@@ -6,13 +6,16 @@ ddata = {
     '社交图标': (760, 53, (203, 141, 116)),
     '公会图标': (571, 142, (216, 92, 7)),
     '战斗图标': (604, 57, (199, 192, 211)),
+    '活动图标': (841, 51, (48, 63, 7)),
     '挑战模式图标': (746, 215, (235, 174, 55)),
     '挑战房间新建位置': (476, 280, (114, 67, 32)),
     '挑战房间添加机器人': (547, 226, (128, 61, 16)),
     '挑战房间点击开始': (955, 470, (118, 10, 14)),
     '退出战斗按钮': (985, 13, (159, 71, 78)),
     '确认退出战斗': (433, 344, (255, 229, 71)),
-    '关闭竞技大厅': (914, 43, (255, 231, 120))
+    '关闭竞技大厅': (914, 43, (255, 231, 120)),
+    '打气球开始': (500, 520, (217, 91, 21)),
+    '轮到自己回合': (494, 169, (255, 190, 112))
 }
 
 if __name__ == '__main__':
