@@ -185,10 +185,11 @@ class Status:
                                             (ddtank.win32api.MapVirtualKey(keycode, 0) << 16) | 0XC0000001)
         return True
 
-    def capture(self, position: tuple = (0, 0, 1000, 600)) -> ddtank.np.ndarray:
+    def capture(self, position: tuple = (0, 0, 1000, 600), save_capture: bool = False) -> ddtank.np.ndarray:
         """
         对角色游戏窗口执行截图操作
         :param position: 指明截图位置的元组，分别为左上角x坐标、左上角y坐标、宽度、高度，默认为(0, 0, 1000, 600)即整个窗口
+        :param save_capture: 是否保存截图。默认保存图片的路径为: ./capture/capture.png
         :return: 返回cv2格式的图片
         """
         x, y, w, h = position
@@ -205,7 +206,12 @@ class Status:
         ddtank.win32gui.DeleteObject(save_bit_map.GetHandle())
         mfc_dc.DeleteDC()
         save_dc.DeleteDC()
-        return ddtank.cv2.cvtColor(img, ddtank.cv2.COLOR_RGBA2RGB)
+        img = ddtank.cv2.cvtColor(img, ddtank.cv2.COLOR_RGBA2RGB)
+        if save_capture:
+            if not ddtank.os.path.exists('./capture'):
+                ddtank.os.mkdir('./capture')
+            ddtank.cv2.imwrite('./capture/capture.png', img)
+        return img
 
     def ocr(self, model: str) -> Union[int, float, str, type(None)]:
         """
@@ -302,13 +308,15 @@ class Status:
             return True
         return False
 
-    def find_image(self, template_image: ddtank.np.ndarray, position: tuple = (0, 0, 1000, 600)) -> tuple:
+    def find_image(self, template_image_name: str, position: tuple = (0, 0, 1000, 600)) -> tuple:
         """
-        寻找指定图像位置
-        :param template_image: 所要寻找的图片
+        寻找指定图像位置，需要先调用load_image方法指定图片资源文件夹路径
+        :param template_image_name: 所要寻找的图片
         :param position: 寻找图片的范围: (x1, y1, x2, y2)，默认为全部
         :return: 返回图片中心点坐标元组
         """
+        assert self.image_path
+        template_image = ddtank.cv2.imread(self.image_path + '/' + template_image_name)
         x1, y1, x2, y2 = position
         image = self.capture()
         image = ddtank.cv2.cvtColor(image, ddtank.cv2.COLOR_BGR2GRAY)
@@ -390,6 +398,44 @@ class Status:
 
         return white_box, blue_point
 
+    # 顶级操作
+    def shot(self, shot_angle: Union[int, tuple], shot_strength: int, shot_item: str):
+        """
+        综合模拟发射炮弹操作
+        :param shot_angle: 发射的角度，若传递一个元组则执行变角操作
+        :param shot_strength: 发射的力度
+        :param shot_item: 使用的道具按键，多个道具之间用','分隔
+        :return: 无返回值
+        """
+        self.press(shot_item)
+        if type(shot_angle) == int:
+            self.change_angle(self.ocr('angle'), shot_angle)
+            self.press_shot(shot_strength)
+        elif type(shot_angle) == type:
+            self.change_angle(self.ocr('angle'), shot_angle[0])
+            self.press_shot(shot_strength)
+            for i in range(1, len(shot_angle)):
+                self.sleep(500)
+                self.change_angle(self.ocr('angle'), shot_angle[i])
+
+    def move(self, move_face: str, move_period: int, reverse_face: bool = False):
+        """
+        角色移动
+        :param move_face: 移动朝向
+        :param move_period: 移动时间(毫秒)
+        :param reverse_face: 移动完后是否逆转朝向
+        :return: 无返回值
+        """
+        if move_face in ['left', 'l', '左']:
+            self.press('A')
+            self.press('A', period=move_period)
+            if reverse_face:
+                self.press('D')
+        elif move_face in ['right', 'r', '右']:
+            self.press('D')
+            self.press('D', period=move_period)
+            if reverse_face:
+                self.press('A')
 
 
 
